==> gyro_0.2.0.tar.gz: gyro/README.md <==
# gyro: stuff for 3D hyperbolic geometry

<!-- badges: start -->
[![R-CMD-check](https://github.com/stla/gyro/workflows/R-CMD-check/badge.svg)](https://github.com/stla/gyro/actions)
<!-- badges: end -->

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/translatedIcosahedra.gif)

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/BarthLike.gif)

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/strangeConvexHull.gif)

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/icosahedron_varying_s.gif)

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/triakisIcosahedron.gif)

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/icosahedron_dynamic_colors.gif)

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/pentagrammicPrism.gif)

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/triakisOctahedron.gif)

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/pyramids.gif)

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/GreatDeltoidalIcositetrahedron.gif)

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/SmallIcosihemidodecahedron.gif)

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/gircope.gif)

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/truncatedGreatDodecahedron.gif)

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/CastellatedRhombicosidodecahedralPrism.gif)

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/rhombicTriacontahedron.gif)

==> gyro_1.0.0.tar.gz: gyro/README.md <==
# gyro: stuff for hyperbolic geometry with R

<!-- badges: start -->
[![R-CMD-check](https://github.com/stla/gyro/workflows/R-CMD-check/badge.svg)](https://github.com/stla/gyro/actions)
<!-- badges: end -->

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/translatedIcosahedra.gif)

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/BarthLike.gif)

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/strangeConvexHull.gif)

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/icosahedron_varying_s.gif)

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/triakisIcosahedron.gif)

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/icosahedron_dynamic_colors.gif)

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/pentagrammicPrism.gif)

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/triakisOctahedron.gif)

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/pyramids.gif)

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/GreatDeltoidalIcositetrahedron.gif)

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/SmallIcosihemidodecahedron.gif)

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/gircope.gif)

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/truncatedGreatDodecahedron.gif)

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/CastellatedRhombicosidodecahedralPrism.gif)

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/rhombicTriacontahedron.gif)

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/htiling.png)

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/hdelaunay.png)

![](https://raw.githubusercontent.com/stla/gyro/main/inst/images/Uhdelaunay.png)


## License

This package is provided under the GPL-3 license. It uses the C++ library 
CGAL. If you wish to use CGAL for commercial purposes, you must obtain a 
license from the [GeometryFactory](https://geometryfactory.com).


## Blog post

I wrote a [blog post](https://laustep.github.io/stlahblog/posts/HyperbolicGircope.html) involving **gyro**.
